@@ -1,6 +1,6 @@
 package Form::Tiny;
-$Form::Tiny::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::VERSION = '2.132';
+$Form::Tiny::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::VERSION = '2.1801';
 use v5.10;
 use strict;
 use warnings;
@@ -164,7 +164,8 @@ Form::Tiny - Input validator centered around Type::Tiny
 
 =head1 DESCRIPTION
 
-Form::Tiny is a customizable hashref validator with DSL for form building.
+Form::Tiny is a customizable hashref validator with form building
+Domain-Specific Language (DSL).
 
 =head1 DOCUMENTATION INDEX
 
@@ -194,7 +195,9 @@ Form::Tiny is a customizable hashref validator with DSL for form building.
 
 =head1 IMPORTING
 
-When imported, Form::Tiny will turn a package into a Moo class that does the L<Form::Tiny::Form> role. It will also install helper functions in your package that act as a domain-specific language (DSL) for building your form.
+When imported, Form::Tiny will turn a package into a Moo class that does the
+L<Form::Tiny::Form> role. It will also install helper functions in your package
+that act as a domain-specific language (DSL) for building your form.
 
 	package MyForm;
 
@@ -207,17 +210,22 @@ When imported, Form::Tiny will turn a package into a Moo class that does the L<F
 	# external plugins
 	use Form::Tiny plugins => ['Diva'];
 
-After C<use Form::Tiny> statement, your package gains all the Moo keywords, some Form::Tiny keywords (see L</"Available import flags">) and all L<Form::Tiny::Form> methods.
+After C<use Form::Tiny> statement, your package gains all the Moo keywords,
+some Form::Tiny keywords (see L</"Available import flags">) and all
+L<Form::Tiny::Form> methods.
 
 =head2 Available import flags
 
-No matter which flag was used in import, using C<Form::Tiny> always installs these functions: C<form_field form_cleaner form_hook>
+No matter which flag was used in import, using C<Form::Tiny> always installs
+these functions: C<form_field form_cleaner form_hook>
 
 =over
 
 =item * C<-nomoo>
 
-This flag stops Form::Tiny from importing Moo into your namespace. Unless you use a different class system (like L<Moose>) will have to declare your own constructor.
+This flag stops Form::Tiny from importing Moo into your namespace. Unless you
+use a different class system (like L<Moose>) will have to declare your own
+constructor.
 
 =item * C<-filtered>
 
@@ -231,7 +239,9 @@ This flag makes your form check for input data strictness before the validation.
 
 =item * C<< plugins => ['Plugin1', '+Full::Namespace::To::Plugin2'] >>
 
-Load plugins into Form::Tiny. Plugins may introduce additional keywords, mix in roles or add metaclass roles. See L<Form::Tiny::Plugin> for details on how to implement a plugin.
+Load plugins into Form::Tiny. Plugins may introduce additional keywords, mix in
+roles or add metaclass roles. See L<Form::Tiny::Plugin> for details on how to
+implement a plugin.
 
 =back
 
@@ -243,13 +253,26 @@ Load plugins into Form::Tiny. Plugins may introduce additional keywords, mix in
 	form_field $coderef;
 	form_field($object); # watch out for indirect method call!
 
-This helper declares a new field for your form. Each style of calling this function should contain keys that meet the specification of L<Form::Tiny::FieldDefinition>, or an object of this class.
+This helper declares a new field for your form. Each style of calling this
+function should contain keys that meet the specification of
+L<Form::Tiny::FieldDefinition>, or an object of this class.
 
-In the first (hash) version, C<%arguments> need to be a plain hash (not a hashref) and should B<not> include the C<name> in the hash, since it will be overriden by the first argument C<$name>. This form also sets the context for the form being built: see L<Form::Tiny::Manual/"Context"> for details.
+In the first (hash) version, C<%arguments> need to be a plain hash (not a
+hashref) and should B<not> include the C<name> in the hash, since it will be
+overriden by the first argument C<$name>. This form also sets the context for
+the form being built: see L<Form::Tiny::Manual/"Context"> for details.
 
-In the second (coderef) version, C<$coderef> gets passed the form instance as its only argument and should return a hash reference or a constructed object of L<Form::Tiny::FieldDefinition>. Unlike the first call style, hashref B<must> contain a C<name>. Note that this creates I<dynamic field>, which will be resolved later, before each form validation. Generally, you should avoid using dynamic fields and only use them when there is something special that you are trying to achieve.
+In the second (coderef) version, C<$coderef> gets passed the form instance as
+its only argument and should return a hash reference or a constructed object of
+L<Form::Tiny::FieldDefinition>. Unlike the first call style, hashref B<must>
+contain a C<name>. Note that this creates I<dynamic field>, which will be
+resolved later, before each form validation. Generally, you should avoid using
+dynamic fields and only use them when there is something special that you are
+trying to achieve.
 
-If you need a subclass of the default implementation, and you don't need a dynamic field, you can use the third style of the call, which takes a constructed object of L<Form::Tiny::FieldDefinition> or its subclass.
+If you need a subclass of the default implementation, and you don't need a
+dynamic field, you can use the third style of the call, which takes a
+constructed object of L<Form::Tiny::FieldDefinition> or its subclass.
 
 =head3 form_message
 
@@ -257,13 +280,19 @@ If you need a subclass of the default implementation, and you don't need a dynam
 		$type1 => $message1,
 		$type2 => $message2;
 
-Override form default error messages, possibly multiple at a time. Types can be any of C<Required> (when a mandatory field is missing), C<IsntStrict> (when form is strict and the check for it fails) and C<InvalidFormat> (when passed input format is not a hash reference) - currently only those types have their own dedicated error message.
+Override form default error messages, possibly multiple at a time. Types can be
+any of C<Required> (when a mandatory field is missing), C<IsntStrict> (when
+form is strict and the check for it fails) and C<InvalidFormat> (when passed
+input format is not a hash reference) - currently only those types have their
+own dedicated error message.
 
 =head3 form_hook
 
 	form_hook $stage => $coderef;
 
-This creates a new hook for C<$stage>. Each stage may have multiple hooks and each will pass different arguments to the C<$coderef>. Refer to L<Form::Tiny::Manual/Hooks> for details.
+This creates a new hook for C<$stage>. Each stage may have multiple hooks and
+each will pass different arguments to the C<$coderef>. Refer to
+L<Form::Tiny::Manual/Hooks> for details.
 
 =head3 form_cleaner
 
@@ -276,7 +305,11 @@ A shortcut for C<< form_hook cleanup => $coderef; >>.
 	# uses current context
 	field_validator $message => $coderef;
 
-Adds an additional custom validator, ran after the type of the field is validated. C<$message> should be something that can present itself as a string. If for a given input parameter C<$coderef> returns false, that message will be added to form errors for that field. See L<Form::Tiny::Manual/"Additional validators"> for details.
+Adds an additional custom validator, ran after the type of the field is
+validated. C<$message> should be something that can present itself as a string.
+If for a given input parameter C<$coderef> returns false, that message will be
+added to form errors for that field.
+See L<Form::Tiny::Manual/"Additional validators"> for details.
 
 See L<Form::Tiny::Manual/"Context"> for details on context.
 
@@ -284,7 +317,9 @@ See L<Form::Tiny::Manual/"Context"> for details on context.
 
 	form_filter $type, $coderef;
 
-Filters the input value before the validation. C<$type> should be a Type::Tiny (or compatible) type check. For each input field that passes that check, C<$coderef> will be ran.
+Filters the input value before the validation. C<$type> should be a Type::Tiny
+(or compatible) type check. For each input field that passes that check,
+C<$coderef> will be ran.
 
 See L<Form::Tiny::Manual/"Filters"> for details on filters.
 
@@ -301,9 +336,8 @@ See L<Form::Tiny::Manual/"Context"> for details on context.
 
 	form_trim_strings;
 
-This helper takes no arguments, but causes your form to filter string values by calling L<Form::Tiny::Utils::trim> on them.
-
-This was enabled by default once. Refer to L<Form::Tiny::Manual::Compatibility/"Filtered forms no longer trim strings by default"> for details.
+This helper takes no arguments, but causes your form to filter string values by
+calling L<Form::Tiny::Utils::trim> on them.
 
 =head1 TODO
 
@@ -321,9 +355,15 @@ This was enabled by default once. Refer to L<Form::Tiny::Manual::Compatibility/"
 
 Bartosz Jarzyna E<lt>bbrtj.pro@gmail.comE<gt>
 
+=head2 Contributors
+
+In no particular order:
+
+Diab Jerius (CPAN: DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020 - 2022 by Bartosz Jarzyna
+Copyright (C) 2020 - 2023 by Bartosz Jarzyna
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
