@@ -1,6 +1,6 @@
 package Form::Tiny::Error;
-$Form::Tiny::Error::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::VERSION = '2.132';
+$Form::Tiny::Error::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::VERSION = '2.1801';
 use v5.10;
 use strict;
 use warnings;
@@ -15,9 +15,9 @@ use overload
 
 has 'field' => (
 	is => 'ro',
-	isa => Maybe [Str],
+	isa => Str,
 	writer => 'set_field',
-	default => sub { undef },
+	predicate => 'has_field',
 );
 
 has 'error' => (
@@ -47,18 +47,18 @@ sub as_string
 
 	# Internal use only
 	package Form::Tiny::Error::NestedFormError;
-$Form::Tiny::Error::NestedFormError::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::NestedFormError::VERSION = '2.132';
-	use parent -norequire, 'Form::Tiny::Error';
+$Form::Tiny::Error::NestedFormError::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::NestedFormError::VERSION = '2.1801';
+use parent -norequire, 'Form::Tiny::Error';
 
 }
 
 {
 
 	package Form::Tiny::Error::InvalidFormat;
-$Form::Tiny::Error::InvalidFormat::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::InvalidFormat::VERSION = '2.132';
-	use parent -norequire, 'Form::Tiny::Error';
+$Form::Tiny::Error::InvalidFormat::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::InvalidFormat::VERSION = '2.1801';
+use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
 	{
@@ -69,9 +69,9 @@ $Form::Tiny::Error::InvalidFormat::VERSION = '2.132';
 {
 
 	package Form::Tiny::Error::Required;
-$Form::Tiny::Error::Required::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::Required::VERSION = '2.132';
-	use parent -norequire, 'Form::Tiny::Error';
+$Form::Tiny::Error::Required::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::Required::VERSION = '2.1801';
+use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
 	{
@@ -82,9 +82,9 @@ $Form::Tiny::Error::Required::VERSION = '2.132';
 {
 
 	package Form::Tiny::Error::IsntStrict;
-$Form::Tiny::Error::IsntStrict::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::IsntStrict::VERSION = '2.132';
-	use parent -norequire, 'Form::Tiny::Error';
+$Form::Tiny::Error::IsntStrict::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::IsntStrict::VERSION = '2.1801';
+use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
 	{
@@ -95,9 +95,9 @@ $Form::Tiny::Error::IsntStrict::VERSION = '2.132';
 {
 
 	package Form::Tiny::Error::DoesNotValidate;
-$Form::Tiny::Error::DoesNotValidate::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Error::DoesNotValidate::VERSION = '2.132';
-	use parent -norequire, 'Form::Tiny::Error';
+$Form::Tiny::Error::DoesNotValidate::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Error::DoesNotValidate::VERSION = '2.1801';
+use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
 	{
@@ -131,11 +131,14 @@ Form::Tiny::Error - form error wrapper
 
 =head1 DESCRIPTION
 
-The form errors class features field name which caused validation error, error message and automatic stringification.
+The form errors class features field name which caused validation error, error
+message and automatic stringification.
 
-The C<< $error->error >> can return a nested error object in case of nested forms.
+The C<< $error->error >> can return a nested error object in case of nested
+forms.
 
-A couple of in-place subclasses are provided to differentiate the type of error which occured. These are:
+A couple of in-place subclasses are provided to differentiate the type of error
+which occured. These are:
 
 =over
 
