@@ -1,6 +1,6 @@
 package Form::Tiny::FieldDefinitionBuilder;
-$Form::Tiny::FieldDefinitionBuilder::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::FieldDefinitionBuilder::VERSION = '2.132';
+$Form::Tiny::FieldDefinitionBuilder::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::FieldDefinitionBuilder::VERSION = '2.1801';
 use v5.10;
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ use Types::Standard qw(HashRef);
 use Form::Tiny::FieldDefinition;
 use Form::Tiny::Utils qw(has_form_meta);
 
-has 'data' => (
+has 'build_data' => (
 	is => 'ro',
 	required => 1,
 );
@@ -21,13 +21,14 @@ has 'addons' => (
 	is => 'ro',
 	isa => HashRef,
 	default => sub { {} },
+	init_arg => undef,
 );
 
 sub build
 {
 	my ($self, $context) = @_;
 
-	my $data = $self->data;
+	my $data = $self->build_data;
 	my $dynamic = ref $data eq 'CODE';
 	if ($dynamic && defined blessed $context) {
 		croak 'building a dynamic field definition requires Form::Tiny form'
@@ -50,7 +51,7 @@ sub build
 			$self->name;
 	}
 
-	$definition->addons($self->addons);
+	$definition->set_addons($self->addons);
 
 	return $definition;
 }
