@@ -1,13 +1,13 @@
 package Form::Tiny::Form;
-$Form::Tiny::Form::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Form::VERSION = '2.132';
+$Form::Tiny::Form::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Form::VERSION = '2.1801';
 use v5.10;
 use strict;
 use warnings;
 use Types::Standard qw(Maybe ArrayRef InstanceOf HashRef Bool);
 use Carp qw(croak);
 use Scalar::Util qw(blessed);
-use List::Util qw(any);
+use List::Util qw(first);
 
 use Form::Tiny::Error;
 use Form::Tiny::Utils qw(try);
@@ -163,6 +163,19 @@ sub _ft_validate_nested
 	}
 }
 
+sub _ft_find_field
+{
+	my ($self, $name, $raise) = @_;
+
+	my $def = first { $_->name eq $name } @{$self->field_defs};
+
+	if ($raise && !defined $def) {
+		croak "form does not contain a field definition for $name";
+	}
+
+	return $def;
+}
+
 sub valid
 {
 	my ($self) = @_;
@@ -243,11 +256,8 @@ sub add_error
 	}
 
 	# check if the field exists
-	for my $name ($error->field) {
-		croak "form does not contain a field definition for $name"
-			if defined $name && !any { $_->name eq $name }
-			@{$self->field_defs};
-	}
+	$self->_ft_find_field($error->field, 1)
+		if $error->has_field;
 
 	# unwrap nested form errors
 	$error = $error->error
@@ -275,6 +285,14 @@ sub has_errors
 	return @{$_[0]->errors} > 0;
 }
 
+sub value
+{
+	my ($self, $field_name) = @_;
+	my $field_def = $self->_ft_find_field($field_name, 1);
+
+	return $field_def->get_name_path->follow($self->fields);
+}
+
 1;
 
 __END__
@@ -289,15 +307,18 @@ See L<Form::Tiny::Manual>
 
 =head1 DESCRIPTION
 
-This role gets automatically mixed in by importing L<Form::Tiny> into your namespace.
+This role gets automatically mixed in by importing L<Form::Tiny> into your
+namespace.
 
 =head1 ADDED INTERFACE
 
-This section describes the interface added to your class after mixing in the Form::Tiny role.
+This section describes the interface added to your class after mixing in the
+Form::Tiny role.
 
 =head2 ATTRIBUTES
 
-Each of the attributes can be accessed by calling its name as a function on Form::Tiny object.
+Each of the attributes can be accessed by calling its name as a function on
+Form::Tiny object.
 
 =head3 input
 
@@ -307,29 +328,36 @@ B<writer:> I<set_input>
 
 =head3 fields
 
-Contains the validated and cleaned fields set after the validation is complete. Cannot be specified in the constructor.
+Contains the validated and cleaned fields set after the validation is complete.
+Cannot be specified in the constructor.
 
 =head3 field_defs
 
-Contains an array reference of L<Form::Tiny::FieldDefinition> instances fetched from the metaclass with context of current instance. Rebuilds everytime new input data is set.
+Contains an array reference of L<Form::Tiny::FieldDefinition> instances fetched
+from the metaclass with context of current instance. Rebuilds everytime new
+input data is set.
 
 =head3 errors
 
-Contains an array reference of form errors which were detected by the last performed validation. Each error is an instance of L<Form::Tiny::Error>.
+Contains an array reference of form errors which were detected by the last
+performed validation. Each error is an instance of L<Form::Tiny::Error>.
 
 B<predicate:> I<has_errors>
 
 =head2 METHODS
 
-This section describes standalone methods available in the module - they are not directly connected to any of the attributes.
+This section describes standalone methods available in the module - they are
+not directly connected to any of the attributes.
 
 =head3 new
 
-This is a Moose-flavored constructor for the class. It accepts a hash or hash reference of parameters, which are the attributes specified above.
+This is a Moose-flavored constructor for the class. It accepts a hash or hash
+reference of parameters, which are the attributes specified above.
 
 =head3 valid
 
-Performs the validation and returns a boolean which indicates whether the form is valid or not.
+Performs the validation and returns a boolean which indicates whether the form
+is valid or not.
 
 Accepts no arguments. Input must be set before calling this method.
 
@@ -337,19 +365,50 @@ Accepts no arguments. Input must be set before calling this method.
 
 =head3 validate
 
-These methods are here to ensure that a Form::Tiny instance can be used as a type validator itself by other form classes.
+These methods are here to ensure that a Form::Tiny instance can be used as a
+type validator itself by other form classes.
 
-I<check> returns a boolean value that indicates whether the validation of input data was successful.
+I<check> returns a boolean value that indicates whether the validation of input
+data was successful.
 
-I<validate> does the same thing, but instead of returning a boolean it returns a list of errors that were detected, or undef if none.
+I<validate> does the same thing, but instead of returning a boolean it returns
+a list of errors that were detected, or undef if none.
 
 Both methods take input data as the only argument.
 
+=head3 value
+
+	if ($form->valid) {
+		my $value = $form->value('field_name');
+		my $values_array_ref = $form->value('array.*');
+	}
+
+Can be used to interact with L</fields> hashref indirectly with key safety checks.
+
+After validation, this method returns form value of the given field. If the
+form was not yet validated or the validation was unsuccessful, returns
+C<undef>.
+
+Accepts a single argument: a field name. Will raise an exception if such field
+was not defined.
+
+If the field contains an array (C<*>) will return an array reference of all
+values for that field. Order of those values will be the same as in the input
+array(s).
+
+I<Note:> currently, the field name passed must be a full field name (not a part
+of field name). For example, passing C<hash.hash> when the field is specified
+as C<hash.hash.field> will raise an exception. This may change in the future.
+
 =head3 errors_hash
 
-Helper method which returns errors much like the C<errors> form attribute, but in a hash reference with form field names as keys. Errors not assigned to any specific field end up in empty string key. The values are array references of error messages (strings).
+Helper method which returns errors much like the C<errors> form attribute, but
+in a hash reference with form field names as keys. Errors not assigned to any
+specific field end up in empty string key. The values are array references of
+error messages (strings).
 
-Each field will only be present in the hash if it has an error assigned to it. If no errors are present, the hash will be empty.
+Each field will only be present in the hash if it has an error assigned to it.
+If no errors are present, the hash will be empty.
 
 It allows you to get errors in format which is easier to navigate:
 
@@ -370,5 +429,6 @@ It allows you to get errors in format which is easier to navigate:
 	$form->add_error($field_name => $error_string);
 	$form->add_error($error_object);
 
-Adds an error to the form. If C<$error_object> style is used, it must be an instance of L<Form::Tiny::Error>.
+Adds an error to the form. If C<$error_object> style is used, it must be an
+instance of L<Form::Tiny::Error>.
 
