@@ -1,6 +1,6 @@
 package Form::Tiny::Meta;
-$Form::Tiny::Meta::VERSION = '2.13_2'; # TRIAL
-$Form::Tiny::Meta::VERSION = '2.132';
+$Form::Tiny::Meta::VERSION = '2.18_01'; # TRIAL
+$Form::Tiny::Meta::VERSION = '2.1801';
 use v5.10;
 use strict;
 use warnings;
@@ -100,7 +100,7 @@ sub set_package
 		no warnings 'redefine';
 
 		*{"${package}::form_meta"} = sub {
-			return get_package_form_meta(ref $_[0] || $_[0]);
+			goto \&get_package_form_meta;
 		};
 		set_subname "${package}::form_meta", *{"${package}::form_meta"};
 	}
@@ -236,7 +236,7 @@ sub add_field
 		$scalar_param = {@parameters, name => $scalar_param};
 	}
 
-	my $builder = Form::Tiny::FieldDefinitionBuilder->new(data => $scalar_param)->build;
+	my $builder = Form::Tiny::FieldDefinitionBuilder->new(build_data => $scalar_param)->build;
 	push @{$self->fields}, $builder;
 
 	$self->set_dynamic(1)
@@ -357,7 +357,7 @@ sub _build_blueprint
 		my ($def) = @_;
 
 		if ($def->is_subform && $recurse) {
-			my $meta = get_package_form_meta(ref $def->type);
+			my $meta = get_package_form_meta($def->type);
 			return $meta->blueprint($def->type, %params);
 		}
 
@@ -366,7 +366,6 @@ sub _build_blueprint
 
 	my $transform = $params{transform} // $transform_base;
 
-
 	# croak, since we don't know anything about dynamic fields in static context
 	croak "Can't create a blueprint of a dynamic form"
 		if $self->is_dynamic && !$context;
